package billing.option3;

import billing.existing.BillingContext;
import billing.existing.Calculator;
import junit.framework.TestCase;

import java.math.BigDecimal;

/**
 * Tests the <code>TestTaxCalculator</code> with a <code>MockCalculator</code>
 */
public class TestTaxCalculator extends TestCase
{
   public static final BigDecimal ORIGINAL_CHARGE = new BigDecimal("100");
   public static final BigDecimal TAX = new BigDecimal("0.10");

   public void testTaxCalculator()
   {
      MockCalculator originalCalculator = new MockCalculator(ORIGINAL_CHARGE);
      TaxCalculator taxCalculator = new TaxCalculator(originalCalculator, TAX);

      // use dummy values, these are not used in the mock calculator
      BillingContext context = new BillingContext(null, null);

      // check that the charge is 100 * 1.1 = 110
      assertEquals("charge not as expected", 110, taxCalculator.calculate(context).intValue());
   }

   private static class MockCalculator implements Calculator
   {
      private BigDecimal charge;

      public MockCalculator(BigDecimal charge)
      {
         this.charge = charge;
      }

      public BigDecimal calculate(BillingContext context)
      {
         return charge;
      }
   }
}
